@@ -1,7 +1,7 @@
 package t::DBQuery;
 
 use Test::Base -Base;
-use IPC::Run3 ();
+#use IPC::Run3 ();
 use FindBin;
 use Data::Dumper;
 
@@ -22,7 +22,6 @@ sub run_test ($)
 {
     my $block = shift;
     my $name = $block->name;
-#	print Dumper $block;
 
     if (defined $block->linux_only && ! $is_linux)
 	{
